@@ -5,7 +5,7 @@ use warnings;
 use Encode::Locale;
 use Encode;
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 sub new {
     my ( $self, %opt ) = @_;
@@ -15,6 +15,15 @@ sub new {
     bless {%opt}, $module;
 }
 
+sub suffix {
+    return '';
+}
+
+sub main {
+    my ($self, $bk, %opt) = @_;
+    return $opt{output};
+}
+
 sub format_item_output {
     my ( $self, $bk, $o ) = @_;
     if ( ! $o->{output} ) {
@@ -37,8 +46,6 @@ sub format_default_filename {
     return encode( locale => $f );
 }
 
-sub suffix {
-    return '';
-}
+
 
 1;
